from typing import overload
import typing

import QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels
import System


class BSModel(System.Object):
    """
    This example demonstrates how to add options for a given underlying equity security.
    It also shows how you can prefilter contracts easily based on strikes and expirations, and how you
    can inspect the option chain to pick a specific option contract to trade.
    """

    class EPutCall(System.Enum):
        """This class has no documentation."""

        Call = 0

        Put = 1

    PutCall: int
    """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall enum."""

    @staticmethod
    def GetDelta(S: float, X: float, q: float, r: float, sigma: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> float:
        ...

    @staticmethod
    def GetGamma(S: float, X: float, q: float, r: float, sigma: float, t: float) -> float:
        ...

    @staticmethod
    def GetImpliedVol(S: float, X: float, q: float, r: float, optionPrice: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall, accuracy: float, maxIterations: int) -> float:
        ...

    @staticmethod
    def GetImpliedVolBisection(S: float, X: float, q: float, r: float, optionPrice: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall, accuracy: float, maxIterations: int) -> float:
        ...

    @staticmethod
    def GetOptionValue(S: float, X: float, q: float, r: float, sigma: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> float:
        ...

    @staticmethod
    def GetRho(S: float, X: float, q: float, r: float, sigma: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> float:
        ...

    @staticmethod
    def GetTheta(S: float, X: float, q: float, r: float, sigma: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> float:
        ...

    @staticmethod
    def GetVega(S: float, X: float, q: float, r: float, sigma: float, t: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> float:
        ...

    @staticmethod
    def n(d: float) -> float:
        ...

    @staticmethod
    def N(d: float) -> float:
        ...

    @staticmethod
    def ZakDelta(S: float, X: float, r: float, sigma: float, t: float, cost: float, risk: float, PutCall: QuantConnect.Algorithm.CSharp.LiveStrategy.PricingModels.BSModel.EPutCall) -> typing.Any:
        ...

    @staticmethod
    def ZakDeltaMulti(S: float, r: float, sigma: float, t: float, cost: float, risk: float, delta_multi: float, gamma_multi: float) -> typing.Any:
        ...





from typing import overload
import typing

import QuantConnect
import QuantConnect.Algorithm.CSharp.LiveStrategy.DataType
import QuantConnect.Data.Market
import QuantConnect.Statistics
import System

IEquatable = typing.Any


class AssetAllocationConfig(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def Asset(self) -> float:
        ...

    @Asset.setter
    def Asset(self, value: float):
        ...

    @property
    def StartDate(self) -> typing.Any:
        ...

    @StartDate.setter
    def StartDate(self, value: typing.Any):
        ...

    @property
    def EndDate(self) -> typing.Any:
        ...

    @EndDate.setter
    def EndDate(self, value: typing.Any):
        ...


class DeribitCalendarSpreadTradingConfig(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def MaxSizePerExpiry(self) -> float:
        ...

    @MaxSizePerExpiry.setter
    def MaxSizePerExpiry(self, value: float):
        ...

    @property
    def TargetPosition(self) -> float:
        ...

    @TargetPosition.setter
    def TargetPosition(self, value: float):
        ...

    @property
    def RequiredReturn(self) -> float:
        ...

    @RequiredReturn.setter
    def RequiredReturn(self, value: float):
        ...

    @property
    def MaxCloseCost(self) -> float:
        ...

    @MaxCloseCost.setter
    def MaxCloseCost(self, value: float):
        ...

    @property
    def MinT2M(self) -> float:
        ...

    @MinT2M.setter
    def MinT2M(self, value: float):
        ...

    @property
    def MaxPerpetualTradeVolume(self) -> float:
        ...

    @MaxPerpetualTradeVolume.setter
    def MaxPerpetualTradeVolume(self, value: float):
        ...


class DeribitCallOptionTradingConfig(System.Object):
    """This class has no documentation."""

    @property
    def Contract(self) -> QuantConnect.Data.Market.OptionContract:
        ...

    @Contract.setter
    def Contract(self, value: QuantConnect.Data.Market.OptionContract):
        ...

    @property
    def Quantity(self) -> float:
        ...

    @Quantity.setter
    def Quantity(self, value: float):
        ...

    @property
    def Status(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Statistics.OptionStatus enum."""
        ...

    @Status.setter
    def Status(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Statistics.OptionStatus enum."""
        ...

    @property
    def TradedVolume(self) -> float:
        ...

    @TradedVolume.setter
    def TradedVolume(self, value: float):
        ...

    def __init__(self, contract: QuantConnect.Data.Market.OptionContract, quantity: float, status: QuantConnect.Statistics.OptionStatus, tradedVolume: float) -> None:
        ...


class DeribitParityTradingConfig(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def OptionLotSize(self) -> float:
        ...

    @OptionLotSize.setter
    def OptionLotSize(self, value: float):
        ...

    @property
    def OptionMaxTradeSize(self) -> float:
        ...

    @OptionMaxTradeSize.setter
    def OptionMaxTradeSize(self, value: float):
        ...

    @property
    def TargetOptionPosition(self) -> float:
        ...

    @TargetOptionPosition.setter
    def TargetOptionPosition(self, value: float):
        ...

    @property
    def RequiredAnnualReturn(self) -> float:
        ...

    @RequiredAnnualReturn.setter
    def RequiredAnnualReturn(self, value: float):
        ...

    @property
    def MaxFuturesVolume(self) -> float:
        ...

    @MaxFuturesVolume.setter
    def MaxFuturesVolume(self, value: float):
        ...

    @property
    def MaxT2M(self) -> int:
        ...

    @MaxT2M.setter
    def MaxT2M(self, value: int):
        ...

    @property
    def MinT2M(self) -> int:
        ...

    @MinT2M.setter
    def MinT2M(self, value: int):
        ...

    @property
    def OptionParityTradeMode(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.OptionParityTradeMode enum."""
        ...

    @OptionParityTradeMode.setter
    def OptionParityTradeMode(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.OptionParityTradeMode enum."""
        ...


class FTXOptionForHedge(System.Object):
    """This class has no documentation."""

    @property
    def Underlying(self) -> str:
        ...

    @property
    def Type(self) -> int:
        """This property contains the int value of a member of the QuantConnect.OptionRight enum."""
        ...

    @property
    def Strike(self) -> float:
        ...

    @property
    def Expiry(self) -> typing.Any:
        ...

    @property
    def Size(self) -> float:
        ...

    @property
    def QuoteId(self) -> int:
        ...

    @property
    def IsHedging(self) -> bool:
        ...

    @IsHedging.setter
    def IsHedging(self, value: bool):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    def __init__(self, strike: float, expiry: typing.Any, size: float, quoteId: int, isHedging: bool = False, underlying: str = "BTC", type: QuantConnect.OptionRight = ..., cashDelta: float = 0) -> None:
        ...

    def ToString(self) -> str:
        ...


class LiveAssetAllocation(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def Asset(self) -> float:
        ...

    @Asset.setter
    def Asset(self, value: float):
        ...

    @property
    def HasCrypto(self) -> bool:
        ...

    @HasCrypto.setter
    def HasCrypto(self, value: bool):
        ...

    @property
    def T2M(self) -> float:
        ...

    @T2M.setter
    def T2M(self, value: float):
        ...

    @property
    def T2MUpdateRatio(self) -> float:
        ...

    @T2MUpdateRatio.setter
    def T2MUpdateRatio(self, value: float):
        ...

    @property
    def UpdateStrikes(self) -> bool:
        ...

    @UpdateStrikes.setter
    def UpdateStrikes(self, value: bool):
        ...

    @property
    def StrikeSpread(self) -> float:
        ...

    @StrikeSpread.setter
    def StrikeSpread(self, value: float):
        ...


class OptionInPortfolio(System.Object):
    """This class has no documentation."""

    @property
    def OptionType(self) -> str:
        ...

    @OptionType.setter
    def OptionType(self, value: str):
        ...

    @property
    def Strike(self) -> float:
        ...

    @Strike.setter
    def Strike(self, value: float):
        ...

    @property
    def Volume(self) -> float:
        ...

    @Volume.setter
    def Volume(self, value: float):
        ...

    @property
    def IsCrossUpline(self) -> bool:
        ...

    @IsCrossUpline.setter
    def IsCrossUpline(self, value: bool):
        ...

    @property
    def IsAddOption(self) -> bool:
        ...

    @IsAddOption.setter
    def IsAddOption(self, value: bool):
        ...

    def __init__(self, optionType: str, strike: float, volume: float, isCrossUpline: bool, isAddOption: bool) -> None:
        ...


class Straddle(IEquatable):
    """This class has no documentation."""

    @property
    def CallOption(self) -> QuantConnect.Data.Market.OptionContract:
        ...

    @property
    def PutOption(self) -> QuantConnect.Data.Market.OptionContract:
        ...

    @property
    def Size(self) -> float:
        ...

    @Size.setter
    def Size(self, value: float):
        ...

    @property
    def Expiry(self) -> typing.Any:
        ...

    @property
    def Traded(self) -> bool:
        ...

    @Traded.setter
    def Traded(self, value: bool):
        ...

    def __init__(self, callOption: QuantConnect.Data.Market.OptionContract, putOption: QuantConnect.Data.Market.OptionContract, size: float, traded: bool = False) -> None:
        ...

    @overload
    def Equals(self, that: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Straddle) -> bool:
        ...

    @overload
    def Equals(self, obj: typing.Any) -> bool:
        ...

    def GetDelta(self, underlyingPrice: float, q: float, r: float, sigma: float, timeNow: typing.Any) -> float:
        ...

    def TryAdd(self, straddle: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Straddle) -> bool:
        ...


class Underlying(IEquatable):
    """This class has no documentation."""

    @property
    def CoinPair(self) -> str:
        ...

    @property
    def HasCrypto(self) -> bool:
        ...

    @HasCrypto.setter
    def HasCrypto(self, value: bool):
        ...

    @property
    def HasFutures(self) -> bool:
        ...

    @HasFutures.setter
    def HasFutures(self, value: bool):
        ...

    def __init__(self, coinPair: str, hasCrypto: bool, hasFuturues: bool) -> None:
        ...

    @overload
    def Equals(self, obj: typing.Any) -> bool:
        ...

    @overload
    def Equals(self, that: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> bool:
        ...





from typing import overload
import abc
import typing

import QuantConnectStubsGenerator.Model
import QuantConnectStubsGenerator.Renderer
import System
import System.IO

QuantConnectStubsGenerator_Renderer_ObjectRenderer_T = typing.TypeVar("QuantConnectStubsGenerator_Renderer_ObjectRenderer_T")
QuantConnectStubsGenerator_Renderer_ObjectRenderer_CreateRenderer_TRenderer = typing.TypeVar("QuantConnectStubsGenerator_Renderer_ObjectRenderer_CreateRenderer_TRenderer")


class BaseRenderer(System.Object, metaclass=abc.ABCMeta):
    """This class has no documentation."""

    @property
    def Writer(self) -> System.IO.StreamWriter:
        """This field is protected."""
        ...

    def __init__(self, writer: System.IO.StreamWriter) -> None:
        """This method is protected."""
        ...

    def Write(self, value: str) -> None:
        """This method is protected."""
        ...

    def WriteLine(self, value: str = ...) -> None:
        """This method is protected."""
        ...


class AlgorithmImportsRenderer(QuantConnectStubsGenerator.Renderer.BaseRenderer):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, leanPath: str) -> None:
        ...

    def Render(self) -> None:
        ...


class ObjectRenderer(typing.Generic[QuantConnectStubsGenerator_Renderer_ObjectRenderer_T], QuantConnectStubsGenerator.Renderer.BaseRenderer, metaclass=abc.ABCMeta):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, indentationLevel: int) -> None:
        """This method is protected."""
        ...

    def CreateRenderer(self, indented: bool = True) -> QuantConnectStubsGenerator_Renderer_ObjectRenderer_CreateRenderer_TRenderer:
        """This method is protected."""
        ...

    def Render(self, item: QuantConnectStubsGenerator_Renderer_ObjectRenderer_T) -> None:
        ...

    def Write(self, value: str) -> None:
        """This method is protected."""
        ...

    def WriteLine(self, value: str = ...) -> None:
        """This method is protected."""
        ...

    def WriteSummary(self, summary: str, indented: bool = False) -> None:
        """This method is protected."""
        ...


class ClassRenderer(QuantConnectStubsGenerator.Renderer.ObjectRenderer[QuantConnectStubsGenerator.Model.Class]):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, indentationLevel: int) -> None:
        ...

    def Render(self, cls: QuantConnectStubsGenerator.Model.Class) -> None:
        ...


class ClrStubsRenderer(QuantConnectStubsGenerator.Renderer.BaseRenderer):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter) -> None:
        ...

    def Render(self) -> None:
        ...


class MethodRenderer(QuantConnectStubsGenerator.Renderer.ObjectRenderer[QuantConnectStubsGenerator.Model.Method]):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, indentationLevel: int) -> None:
        ...

    def Render(self, method: QuantConnectStubsGenerator.Model.Method) -> None:
        ...


class NamespaceRenderer(QuantConnectStubsGenerator.Renderer.ObjectRenderer[QuantConnectStubsGenerator.Model.Namespace]):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, indentationLevel: int) -> None:
        ...

    def Render(self, ns: QuantConnectStubsGenerator.Model.Namespace) -> None:
        ...


class PropertyRenderer(QuantConnectStubsGenerator.Renderer.ObjectRenderer[QuantConnectStubsGenerator.Model.Property]):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, indentationLevel: int) -> None:
        ...

    def Render(self, property: QuantConnectStubsGenerator.Model.Property) -> None:
        ...


class PyLoaderRenderer(QuantConnectStubsGenerator.Renderer.BaseRenderer):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter) -> None:
        ...

    def Render(self, ns: str) -> None:
        ...


class SetupRenderer(QuantConnectStubsGenerator.Renderer.BaseRenderer):
    """This class has no documentation."""

    def __init__(self, writer: System.IO.StreamWriter, leanPath: str, outputDirectory: str) -> None:
        ...

    def Render(self) -> None:
        ...





from typing import overload
import datetime
import typing

import MomCrypto.Api
import MomCrypto.DataApi
import System


class MomHistoryData(System.Object):
    """This class has no documentation."""

    @property
    def OpenTime(self) -> datetime.datetime:
        ...

    @OpenTime.setter
    def OpenTime(self, value: datetime.datetime):
        ...

    @property
    def Open(self) -> float:
        ...

    @Open.setter
    def Open(self, value: float):
        ...

    @property
    def High(self) -> float:
        ...

    @High.setter
    def High(self, value: float):
        ...

    @property
    def Low(self) -> float:
        ...

    @Low.setter
    def Low(self, value: float):
        ...

    @property
    def Close(self) -> float:
        ...

    @Close.setter
    def Close(self, value: float):
        ...

    @property
    def BaseVolume(self) -> float:
        ...

    @BaseVolume.setter
    def BaseVolume(self, value: float):
        ...

    @property
    def CloseTime(self) -> datetime.datetime:
        ...

    @CloseTime.setter
    def CloseTime(self, value: datetime.datetime):
        ...

    @property
    def QuoteVolume(self) -> float:
        ...

    @QuoteVolume.setter
    def QuoteVolume(self, value: float):
        ...

    @property
    def TradeCount(self) -> int:
        ...

    @TradeCount.setter
    def TradeCount(self, value: int):
        ...

    @property
    def TakerBuyBaseVolume(self) -> float:
        ...

    @TakerBuyBaseVolume.setter
    def TakerBuyBaseVolume(self, value: float):
        ...

    @property
    def TakerBuyQuoteVolume(self) -> float:
        ...

    @TakerBuyQuoteVolume.setter
    def TakerBuyQuoteVolume(self, value: float):
        ...


class MomQryHistoryData(MomCrypto.Api.MomQryField):
    """This class has no documentation."""

    @property
    def InstrumentId(self) -> str:
        ...

    @InstrumentId.setter
    def InstrumentId(self, value: str):
        ...

    @property
    def TimeStart(self) -> str:
        ...

    @TimeStart.setter
    def TimeStart(self, value: str):
        ...

    @property
    def TimeEnd(self) -> str:
        ...

    @TimeEnd.setter
    def TimeEnd(self, value: str):
        ...

    @property
    def Market(self) -> str:
        ...

    @Market.setter
    def Market(self, value: str):
        ...

    @property
    def DataType(self) -> int:
        ...

    @DataType.setter
    def DataType(self, value: int):
        ...


class MomHistoryDataApi(System.Object):
    """This class has no documentation."""

    def __init__(self, address: str, logger: typing.Any) -> None:
        ...

    def GetAccounts(self) -> typing.List[MomCrypto.Api.MomAccount]:
        ...

    def GetAccountTrades(self, account: str, localId: int = 0, count: int = 1000) -> typing.List[MomCrypto.Api.MomTrade]:
        ...

    def GetFundAccounts(self) -> typing.List[MomCrypto.Api.MomFundAccount]:
        ...

    def GetFundPositions(self, account: str) -> typing.List[MomCrypto.Api.MomFundPosition]:
        ...

    def GetFundTrades(self, account: str, localId: int = 0, count: int = 1000) -> typing.List[MomCrypto.Api.MomFundTrade]:
        ...

    def GetUserPositions(self, user: str) -> typing.List[MomCrypto.Api.MomPosition]:
        ...

    def GetUserTrades(self, user: str, localId: int = 0, count: int = 1000) -> typing.List[MomCrypto.Api.MomTrade]:
        ...

    def QryBinanceHistoryData(self, qryData: MomCrypto.DataApi.MomQryHistoryData) -> str:
        ...

    def QryDeribitHistoryData(self, qryData: MomCrypto.DataApi.MomQryHistoryData) -> str:
        ...

    def QryFtxHistoryData(self, qryData: MomCrypto.DataApi.MomQryHistoryData) -> str:
        ...

    def QryHistoryData(self, qryData: MomCrypto.DataApi.MomQryHistoryData, market: str) -> str:
        ...

    def SendDingMsg(self, text: str, token: str = None, key: str = None) -> None:
        ...


class MomHistoryDataType(System.Enum):
    """This class has no documentation."""

    OneMinute = 0

    ThreeMinutes = 1

    FiveMinutes = 2

    FifteenMinutes = 3

    ThirtyMinutes = 4

    OneHour = 5

    TwoHour = 6

    FourHour = 7

    SixHour = 8

    EightHour = 9

    TwelveHour = 10

    OneDay = 11

    ThreeDay = 12

    OneWeek = 13

    OneMonth = 14





from typing import overload
import datetime
import typing

import QuantConnect
import QuantConnect.Interfaces
import QuantConnect.Parameters
import QuantConnect.Securities
import System
import System.Collections.Generic
import System.Reflection


class ParameterAttribute(System.Attribute):
    """
    Specifies a field or property is a parameter that can be set
    from an AlgorithmNodePacket.Parameters dictionary
    """

    BindingFlags: System.Reflection.BindingFlags = ...
    """Specifies the binding flags used by this implementation to resolve parameter attributes"""

    @property
    def Name(self) -> str:
        """Gets the name of this parameter"""
        ...

    @Name.setter
    def Name(self, value: str):
        """Gets the name of this parameter"""
        ...

    def __init__(self, name: str = None) -> None:
        """
        Initializes a new instance of the ParameterAttribute class
        
        :param name: The name of the parameter. If null is specified then the field or property name will be used
        """
        ...

    @staticmethod
    def ApplyAttributes(parameters: System.Collections.Generic.Dictionary[str, str], instance: typing.Any) -> None:
        """
        Uses reflections to inspect the instance for any parameter attributes.
        If a value is found in the parameters dictionary, it is set.
        
        :param parameters: The parameters dictionary
        :param instance: The instance to set parameters on
        """
        ...

    @staticmethod
    def GetParametersFromAssembly(assembly: System.Reflection.Assembly) -> System.Collections.Generic.Dictionary[str, str]:
        """
        Resolves all parameter attributes from the specified compiled assembly path
        
        :param assembly: The assembly to inspect
        :returns: Parameters dictionary keyed by parameter name with a value of the member type.
        """
        ...

    @staticmethod
    def GetParametersFromType(type: typing.Type) -> System.Collections.Generic.IEnumerable[System.Collections.Generic.KeyValuePair[str, str]]:
        """
        Resolves all parameter attributes from the specified type
        
        :param type: The type to inspect
        :returns: Parameters dictionary keyed by parameter name with a value of the member type.
        """
        ...


class PerformanceAnalysisFrequency(System.Enum):
    """This class has no documentation."""

    # Cannot convert to Python: None = 0

    Weekly = 1

    Daily = 2

    Custom = 3


class PerformanceAnalyserAttribute(System.Attribute):
    """
    Specifies a field or property is a parameter that can be set
    from an AlgorithmNodePacket.Parameters dictionary
    """

    @property
    def LiveAlgorithmID(self) -> str:
        """The live algorithm name that the performance analyser will be applied to"""
        ...

    @LiveAlgorithmID.setter
    def LiveAlgorithmID(self, value: str):
        """The live algorithm name that the performance analyser will be applied to"""
        ...

    @property
    def BenchmarkBacktest(self) -> str:
        """The name of this benchmark backtesting algorithm"""
        ...

    @BenchmarkBacktest.setter
    def BenchmarkBacktest(self, value: str):
        """The name of this benchmark backtesting algorithm"""
        ...

    @property
    def StartDate(self) -> typing.Optional[datetime.datetime]:
        """Start date of the expected period of this performance analysis"""
        ...

    @StartDate.setter
    def StartDate(self, value: typing.Optional[datetime.datetime]):
        """Start date of the expected period of this performance analysis"""
        ...

    @property
    def EndDate(self) -> typing.Optional[datetime.datetime]:
        """End date of the expected period of this performance analysis"""
        ...

    @EndDate.setter
    def EndDate(self, value: typing.Optional[datetime.datetime]):
        """End date of the expected period of this performance analysis"""
        ...

    @property
    def DestOutputFolder(self) -> str:
        """The desstination output directory for the performance analysis results"""
        ...

    @DestOutputFolder.setter
    def DestOutputFolder(self, value: str):
        """The desstination output directory for the performance analysis results"""
        ...

    @property
    def DestOutputFileName(self) -> str:
        """The desstination output file name based on the start and end date"""
        ...

    @DestOutputFileName.setter
    def DestOutputFileName(self, value: str):
        """The desstination output file name based on the start and end date"""
        ...

    @property
    def InitialCashBook(self) -> QuantConnect.Securities.CashBook:
        ...

    @InitialCashBook.setter
    def InitialCashBook(self, value: QuantConnect.Securities.CashBook):
        ...

    @property
    def InitialHoldings(self) -> System.Collections.Generic.Dictionary[str, QuantConnect.Holding]:
        ...

    @InitialHoldings.setter
    def InitialHoldings(self, value: System.Collections.Generic.Dictionary[str, QuantConnect.Holding]):
        ...

    @property
    def Frequency(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Parameters.PerformanceAnalysisFrequency enum."""
        ...

    @Frequency.setter
    def Frequency(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Parameters.PerformanceAnalysisFrequency enum."""
        ...

    @overload
    def __init__(self, StartDate: typing.Union[datetime.datetime, datetime.date], EndDate: typing.Union[datetime.datetime, datetime.date], BenchmarkBacktest: str = ..., DestOutputFolder: str = ..., LiveAlgorithmID: str = ...) -> None:
        """
        Initializes a new instance of the PerformanceAnalyserAttribute class
        
        :param StartDate: the specified start date of this analysis job
        :param EndDate: the specified end date of this analysis job
        :param BenchmarkBacktest: the target backtesting algorithm name to compare with in this analysis job
        :param DestOutputFolder: the destination output folder for live results of this analysis job
        :param LiveAlgorithmID: the live algorithm name that need an analysis
        """
        ...

    @overload
    def __init__(self, BenchmarkBacktest: str = ..., Frequency: QuantConnect.Parameters.PerformanceAnalysisFrequency = ..., DestOutputFolder: str = ..., LiveAlgorithmID: str = ...) -> None:
        """
        Initializes a new instance of the PerformanceAnalyserAttribute class
        
        :param BenchmarkBacktest: the target backtesting algorithm name to compare with in this analysis job
        :param Frequency: the frequency of this performance analysis job
        :param DestOutputFolder: the destination output folder for live results of this analysis job
        :param LiveAlgorithmID: the live algorithm name that need an analysis
        """
        ...

    def InitRolloverPeriod(self) -> None:
        ...

    def IsInvokingBacktest(self) -> bool:
        ...

    def TakePortfolioSnapshot(self, algorithm: QuantConnect.Interfaces.IAlgorithm) -> None:
        ...

    def UpdateRolloverPeriod(self) -> None:
        ...





from typing import overload
import typing

import MomCrypto.Api.Algorithm
import System


class Utils(System.Object):
    """This class has no documentation."""

    @staticmethod
    def CalculateCoinTradePnL(tradeAmount: float, tradePrice: float, updatedAmount: typing.Optional[float], initialAmount: float = 0, initialPrice: float = 0) -> typing.Union[float, float]:
        ...

    @staticmethod
    def CalculateTradePnL(tradeVolume: float, tradePrice: float, updatedVolume: typing.Optional[float], updatedPrice: typing.Optional[float], initialVolume: float = 0, initialPrice: float = 0) -> typing.Union[float, float, float]:
        ...

    @staticmethod
    def GetCoinCloseProfit(volume: float, openPrice: float, closePrice: float, volumeMultiple: float) -> float:
        ...





from typing import overload
import FtxApi.Rest.Enums
import System


class OptionType(System.Enum):
    """This class has no documentation."""

    put = 0

    call = 1


class OrderType(System.Enum):
    """This class has no documentation."""

    limit = 0

    market = 1


class SideType(System.Enum):
    """This class has no documentation."""

    buy = 0

    sell = 1


class TriggerType(System.Enum):
    """This class has no documentation."""

    stop = 0

    trailingStop = 1

    takeProfit = 2





from typing import overload
import datetime
import typing

import Calculators
import Calculators.DataType
import System


class FTXCollateralParameters(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def TotalWeight(self) -> float:
        ...

    @TotalWeight.setter
    def TotalWeight(self, value: float):
        ...

    @property
    def InitialWeight(self) -> float:
        ...

    @InitialWeight.setter
    def InitialWeight(self, value: float):
        ...

    @property
    def IMFFactor(self) -> float:
        ...

    @IMFFactor.setter
    def IMFFactor(self, value: float):
        ...

    def __init__(self, coin: str, totalWeight: float, initialWeight: float, imfFactor: float) -> None:
        ...

    def Copy(self, totalWeight: float) -> Calculators.DataType.FTXCollateralParameters:
        ...


class Holding(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @property
    def Quantity(self) -> float:
        ...

    @property
    def MarkPrice(self) -> float:
        ...

    @property
    def QuoteCurrency(self) -> str:
        ...

    @property
    def SecurityType(self) -> int:
        """This property contains the int value of a member of the Calculators.SecurityType enum."""
        ...

    @property
    def MaintenanceMarginRequirement(self) -> float:
        ...

    @property
    def InitialMarginRequirement(self) -> float:
        ...

    def __init__(self, coin: str, quantity: float, markPrice: float, quoteCurrency: str, securityType: Calculators.SecurityType, maintenanceMarginRequirement: float, initialMarginRequirement: float) -> None:
        ...

    def CalculateCollateralValue(self, collateralConfig: Calculators.DataType.FTXCollateralParameters, isInitial: bool) -> float:
        ...

    def ToString(self) -> str:
        ...


class StopLossInfo(System.Object):
    """This class has no documentation."""

    @property
    def Coin(self) -> str:
        ...

    @Coin.setter
    def Coin(self, value: str):
        ...

    @property
    def StartTime(self) -> datetime.datetime:
        ...

    @StartTime.setter
    def StartTime(self, value: datetime.datetime):
        ...

    @property
    def MaxLossBase(self) -> float:
        ...

    @MaxLossBase.setter
    def MaxLossBase(self, value: float):
        ...

    @property
    def MaxLossRatio(self) -> float:
        ...

    @MaxLossRatio.setter
    def MaxLossRatio(self, value: float):
        ...

    @property
    def MinProfit(self) -> float:
        ...

    @MinProfit.setter
    def MinProfit(self, value: float):
        ...

    @property
    def MaxVentureDays(self) -> int:
        ...

    @MaxVentureDays.setter
    def MaxVentureDays(self, value: int):
        ...

    @property
    def IsStopLoss(self) -> bool:
        ...

    @IsStopLoss.setter
    def IsStopLoss(self, value: bool):
        ...

    def StopLoss(self, currentTime: typing.Union[datetime.datetime, datetime.date], pnl: float, price: float) -> bool:
        ...





from typing import overload
import typing

import Calculators.Estimators
import System
import System.Collections.Generic


class EWMAVolatilityEstimator(System.Object):
    """use r0square as start point, allow empty price list"""

    @property
    def CurrentVolatility(self) -> float:
        ...

    @CurrentVolatility.setter
    def CurrentVolatility(self, value: float):
        ...

    @property
    def Volatilities(self) -> System.Collections.Generic.IList[float]:
        ...

    @Volatilities.setter
    def Volatilities(self, value: System.Collections.Generic.IList[float]):
        ...

    @overload
    def __init__(self, prices: System.Collections.Generic.IList[float], _lambda: float) -> None:
        ...

    @overload
    def __init__(self, price: float, currentVolatility: float, _lambda: float) -> None:
        ...

    def AddPrice(self, price: float) -> None:
        ...

    def AddPrices(self, prices: System.Collections.Generic.IList[float]) -> None:
        ...

    def UpdateEWMAVolatility(self, new_price: float, last_price: float) -> float:
        ...





from typing import overload
import datetime
import typing

import FtxApi.Rest.Models.Markets
import System
import System.Collections.Generic


class Market(System.Object):
    """This class has no documentation."""

    @property
    def Type(self) -> str:
        """"future" or "spot\""""
        ...

    @Type.setter
    def Type(self, value: str):
        """"future" or "spot\""""
        ...

    @property
    def Name(self) -> str:
        ...

    @Name.setter
    def Name(self, value: str):
        ...

    @property
    def Underlying(self) -> str:
        ...

    @Underlying.setter
    def Underlying(self, value: str):
        ...

    @property
    def BaseCurrency(self) -> str:
        ...

    @BaseCurrency.setter
    def BaseCurrency(self, value: str):
        ...

    @property
    def QuoteCurrency(self) -> str:
        ...

    @QuoteCurrency.setter
    def QuoteCurrency(self, value: str):
        ...

    @property
    def Enabled(self) -> bool:
        ...

    @Enabled.setter
    def Enabled(self, value: bool):
        ...

    @property
    def Ask(self) -> typing.Optional[float]:
        ...

    @Ask.setter
    def Ask(self, value: typing.Optional[float]):
        ...

    @property
    def Bid(self) -> typing.Optional[float]:
        ...

    @Bid.setter
    def Bid(self, value: typing.Optional[float]):
        ...

    @property
    def Last(self) -> typing.Optional[float]:
        ...

    @Last.setter
    def Last(self, value: typing.Optional[float]):
        ...

    @property
    def PriceIncrement(self) -> float:
        ...

    @PriceIncrement.setter
    def PriceIncrement(self, value: float):
        ...

    @property
    def SizeIncrement(self) -> float:
        ...

    @SizeIncrement.setter
    def SizeIncrement(self, value: float):
        ...

    @property
    def MinProvideSize(self) -> typing.Optional[float]:
        ...

    @MinProvideSize.setter
    def MinProvideSize(self, value: typing.Optional[float]):
        ...

    def ToString(self) -> str:
        ...


class Orderbook(System.Object):
    """This class has no documentation."""

    @property
    def Bids(self) -> System.Collections.Generic.List[System.Collections.Generic.List[float]]:
        ...

    @Bids.setter
    def Bids(self, value: System.Collections.Generic.List[System.Collections.Generic.List[float]]):
        ...

    @property
    def Asks(self) -> System.Collections.Generic.List[System.Collections.Generic.List[float]]:
        ...

    @Asks.setter
    def Asks(self, value: System.Collections.Generic.List[System.Collections.Generic.List[float]]):
        ...


class Trade(System.Object):
    """This class has no documentation."""

    @property
    def Id(self) -> float:
        ...

    @Id.setter
    def Id(self, value: float):
        ...

    @property
    def Liquidation(self) -> bool:
        ...

    @Liquidation.setter
    def Liquidation(self, value: bool):
        ...

    @property
    def Price(self) -> float:
        ...

    @Price.setter
    def Price(self, value: float):
        ...

    @property
    def Side(self) -> str:
        ...

    @Side.setter
    def Side(self, value: str):
        ...

    @property
    def Size(self) -> float:
        ...

    @Size.setter
    def Size(self, value: float):
        ...

    @property
    def Time(self) -> datetime.datetime:
        ...

    @Time.setter
    def Time(self, value: datetime.datetime):
        ...


